@@ -64,5 +64,8 @@ def get_parser():
     return parser
 
 
-if __name__ == '__main__':
+def main():
     app.run()
+
+if __name__ == '__main__':
+    main()
